# PaperCandy

**PaperCandy** is a loosely coupled training framework for Deep Learning research. It provides an intermediate layer so that the back-end frameworks (such as PyTorch or TensorFlow) can be replaced easily.

## Installation

### For Windows

```shell
pip install paper-candy
```

### For Linux & MacOS

```shell
pip3 install paper-candy
```

### 